@@ -951,7 +951,7 @@ err_split_nl_1 <- function(x,
 err_episodes_checks_0 <- function(date = 1, case_length = 1, episode_type = "fixed", recurrence_length = case_length,
                                   episode_unit = "days", strata = 1, sn = seq_len(length(date)), episodes_max = 1, rolls_max = 1,
                                   case_overlap_methods = 8, recurrence_overlap_methods = case_overlap_methods,
-                                  skip_if_b4_lengths = FALSE, data_source = 1,
+                                  skip_if_b4_lengths = FALSE, data_source = "1",
                                   data_links = "ANY", custom_sort = 1, skip_order = 1, reference_event = "last_record",
                                   case_for_recurrence = FALSE, from_last = FALSE, group_stats = FALSE,
                                   display = "none", case_sub_criteria = NULL, recurrence_sub_criteria = NULL,
@@ -967,7 +967,7 @@ err_episodes_checks_0 <- function(date = 1, case_length = 1, episode_type = "fix
                recurrence_overlap_methods = recurrence_overlap_methods,
                episode_unit = episode_unit,
                display = display,
-               #data_source = data_source,
+               data_source = data_source,
                episodes_max = episodes_max,
                rolls_max = rolls_max,
                skip_if_b4_lengths = skip_if_b4_lengths,
@@ -993,7 +993,7 @@ err_episodes_checks_0 <- function(date = 1, case_length = 1, episode_type = "fix
                        recurrence_length = c("list", "integer", "numeric", "number_line"),
                        episodes_max = c("numeric", "integer"),
                        rolls_max = c("numeric", "integer"),
-                       data_source = c("atomic"),
+                       data_source = c("NULL", "character"),
                        data_links = c("list", "character"),
                        skip_order = c("numeric", "integer"),
                        skip_if_b4_lengths = "logical",
